@@ -194,10 +194,10 @@ def freeze_versions(versions_file, change_install_requires):
 
 def unset_freezed_versions_in_install_requires(buildout_cfg):
     from .package_sets import InstallRequiresPackageSet, to_dict, from_dict
-    install_requires = InstallRequiresPackageSet.from_value(buildout.get("project", "install_requires"))
+    install_requires = InstallRequiresPackageSet.from_value(buildout_cfg.get("project", "install_requires"))
     install_requires_dict = to_dict(install_requires)
-    install_requires_dict.update({key:[] for key, specs in install_requires_dict
-                                  if specs and specs[0] == '>='})
+    install_requires_dict.update({key:[] for key, specs in install_requires_dict.items()
+                                  if specs and specs[-1][0] == '>='})
     install_requires = from_dict(install_requires_dict)
     buildout_cfg.set("project", "install_requires", InstallRequiresPackageSet.to_value(install_requires))
 
@@ -207,6 +207,7 @@ def unfreeze_versions(change_install_requires):
         buildout_cfg.remove_option("buildout", "buildout_versions_file")
         buildout_cfg.remove_option("buildout", "extends")
         buildout_cfg.remove_option("buildout", "versions")
+        buildout_cfg.remove_section("versions")
         if change_install_requires:
             unset_freezed_versions_in_install_requires(buildout_cfg)
 
@@ -218,7 +219,8 @@ def revert_if_failed(keep_leftovers):
     get_tags = lambda: {tag.name:tag for tag in repository.getTags()}
     get_branches = lambda: {branch.name:branch for branch in repository.getBranches()}
     get_head = lambda branch_name: repository.getBranchByName(branch_name).getHead()
-    get_status = lambda: dict(develop=get_head("develop"), master=get_head("master"), tags=get_tags())
+    get_status = lambda: dict(develop=get_head("develop"), master=get_head("master"), tags=get_tags(),
+                              branches=get_branches())
     before = get_status()
     try:
         yield
